/*  annoteps.h -- header file for program annoteps  */

/*  Constants (typeface name constants are defined later)  */

#define	APS_MAXSTRING 20	/* Maximum number of text strings; must
				   match maximum count in PDF file */

#define APS_CONVERT "convert"	/* Name of ImageMagick convert program.
				   If correct version of convert is not
				   found using normal PATH variable,
				   APS_CONVERT should be changed to
				   specify the full path. */

#define APS_INPLACE 0		/* Codes for subcommands */
#define APS_INOUT   1
#define APS_GENIMG  2

#define APS_LTOR 0		/* Codes for each supported string */
#define APS_TTOB 1		/*  orientation			   */
#define APS_BTOT 2

#define APS_TL	0		/* Codes for each supported string */
#define APS_TC  1		/* alignment.  The order of these  */
#define APS_TR  2		/* values should not be changed    */
#define APS_CL  3
#define APS_CC  4
#define APS_CR  5
#define APS_BL  6
#define APS_BC  7
#define APS_BR  8

#define APS_WGHTR 0		/* Codes for character weight */
#define APS_WGHTB 1

#define APS_STYLER 0		/* Codes for character style */
#define APS_STYLEO 1

#define APS_TRANS 0		/* Code for transparency option */
#define APS_OPAQUE 1

/*  Structure definitions  */

struct APS_IMG		/* Structure defining one logical input image */
    {
    long	totimage;	/* Number of images in logical image */
    char	*hname;		/* Array of host names, each CMLEN bytes 
				   long */ 
    long	*dtype;		/* Data type code for each input */
    long	*dlength;	/* Lengths of input values, in bytes */
    long	*window;	/* Window array:  4 values for each
				   input */
    long	totband;	/* Total bands in logical image */
    long	*nband;		/* Number of bands in each image */
    long	*bands;		/* Array of band lists, each containing
				   MAXBND + 1 values */
    long	*offsets;	/* Offsets into main input buffer */
    };

struct APS_TEXT		/* Structure defining one annot'n text block */
    {
    char	text[132];	/* Annotation text */
    long	linepos;	/* Line position of text block */
    long	samppos;	/* Sample postion of text block */
    long	align;		/* Code for text block alignment */
    long	orient;		/* Code for text block orientation */
    long	size;		/* Size of typeface, pixels */
    char	typeface[11];	/* Typeface name */
    long	style;		/* Code for type style */
    long	weight;		/* Code for type weight */
    float	chargrey;	/* Grey level of characters */
    float	backgrnd;	/* Grey level of text background */
    long	transopt;	/* Transparency option */
    double	lookup[256];	/* Lookup table for converting text */
    long	nl;		/* Number of lines in text block */
    long	ns;		/* Number of samples per text line */
    long	slo;		/* Starting line in output window */
    long	sso;		/* Starting sample in output window */
    long	topl;		/* Top line of block in temp. file */ 
    long	lefts;		/* Leftmost sample of block in temp.
				   file */
    };

/*  Names of typeface families supported by ANNOTEPS.

    To use APS_FACENAMETABLE and APS_PSNAMETABLE, use statements of the
    form
	char *facenames[APS_FACECOUNT] = APS_FACENAMETABLE;
	char *psnames[4 * APS_FACECOUNT] = APS_PSNAMETABLE;

    This list may need to be adjusted to reflect locally supported
    faces.  The command "xlsfonts | grep -v '.*-.*-'" gives a list of
    canditate typefaces.  Note, however, that ANNOTEPS processes the
    PostScript commands using the ImageMagick "convert" program which 
    may not be able to process all the typefaces listed by xlsfonts.
*/

#define APS_FACECOUNT 8
#define APS_FACENAMETABLE { \
  "COURIER", \
  "HELVETICA", \
  "TIMES", \
  "AVANTGARDE", \
  "BOOKMAN", \
  "HLVNARROW", \
  "NEWCENTURY", \
  "PALATINO" \
  }

/*  Names recognised by Postscript for each typeface family:  regular,
    oblique, bold, and bold-oblique for each family.
*/

#define APS_PSNAMETABLE { \
  "Courier", "Courier-Oblique", "Courier-Bold", "Courier-BoldOblique", \
  "Helvetica", "Helvetica-Oblique", "Helvetica-Bold", \
   "Helvetica-BoldOblique", \
  "Times-Roman", "Times-Italic", "Times-Bold", "Times-BoldItalic", \
  "AvantGarde-Book", "AvantGarde-BookOblique", "AvantGarde-Demi", \
   "AvantGarde-DemiOblique",  \
  "Bookman-Light", "Bookman-LightItalic", "Bookman-Demi", \
    "Bookman-DemiItalic",  \
  "Helvetica-Narrow", "Helvetica-Narrow-Oblique", \
   "Helvetica-Narrow-Bold", "Helvetica-Narrow-BoldOblique", \
  "Newcenturyschlbk-Roman", "Newcenturyschlbk-Italic", \
   "Newcenturyschlbk-Bold", "Newcenturyschlbk-BoldItalic", \
  "Palatino-Roman", "Palatino-Italic", "Palatino-Bold", \
   "Palatino-BoldItalic" \
  }

/*  Function prototypes  */

void aps_getarg( struct PARBLK *vblock, long *subcmd,
		 struct APS_IMG *input, char *outimg,
		 long *odtype, long *nlo, long *nso, float *outbgrnd,
		 struct APS_TEXT **text, long *nblock, char *tmproot,
		 long *pmsgtim, long *ifminmax );
void aps_bldtxt( long nblock, char *tmproot, long nlo, long nso,
		 struct APS_TEXT *text,long *npixhoriz,
		 long *npixvert );
long aps_instxt( struct PARBLK *vblock, long subcmd,
		 struct APS_IMG *input, char *outimg, long *odtype,
		 long nlo, long nso, float outbgrnd,
		 struct APS_TEXT *text, long nblock, char *tmproot,
		 long npixhoriz, long npixvert, long pmsgtim,
		 long ifminmax);
